import { TMovingDirection } from '@/core/helpers/moving-directions';
import { ILayoutItem, TLayout, TLayoutItem } from '@/components/Grid/layout-definition';
/**
 * Get all static elements.
 * @param  {Array} layout Array of layout objects.
 * @return {Array}        Array of static layout items..
 */
export declare function getStatics(layout: TLayout): ILayoutItem[];
/**
 * Return the bottom coordinate of the layout.
 *
 * @param  {Array} layout Layout array.
 * @return {Number}       Bottom coordinate.
 */
export declare function bottom(layout: TLayout): number;
export declare function cloneLayoutItem(layoutItem: ILayoutItem): TLayoutItem;
export declare function cloneLayout(layout: TLayout): TLayout;
/**
 * Given two layout items, check if they collide.
 *
 * @return {Boolean}   True if colliding.
 */
export declare function collides(l1: ILayoutItem, l2: ILayoutItem): boolean;
/**
 * Returns the first item this layout collides with.
 * It doesn't appear to matter which order we approach this from, although
 * perhaps that is the wrong thing to do.
 *
 * @param  {TLayout}     layout     The entire grid layout.
 * @param  {ILayoutItem} layoutItem Layout item.
 * @return {ILayoutItem|undefined}  A colliding layout item, or undefined.
 */
export declare function getFirstCollision(layout: TLayout, layoutItem: ILayoutItem): ILayoutItem | undefined;
/**
 * Get layout items sorted from top left to right and down.
 *
 * @param  {TLayout} layout  Array of layout objects.
 * @return {TLayout}        Layout, sorted static items first.
 */
export declare function sortLayoutItemsByRowCol(layout: TLayout): TLayout;
/**
 * Compact an item in the layout.
 */
export declare function compactItem(compareWith: TLayout, l: ILayoutItem, verticalCompact: boolean, minPositions?: any): ILayoutItem;
/**
 * Given a layout, compact it. This involves going down each y coordinate and removing gaps
 * between items.
 *
 * @param   {TLayout} layout          Layout.
 * @param   {Boolean} verticalCompact Whether or not to compact the layout vertically.
 * @param   {Object}  minPositions
 * @return  {TLayout}                 Compacted Layout.
 */
export declare function compact(layout: TLayout, verticalCompact: boolean, minPositions?: any): TLayout;
/**
 * Given a layout, make sure all elements fit within its bounds.
 *
 * @param  {Array} layout Layout array.
 * @param  {Number} bounds Number of columns.
 */
export declare function correctBounds(layout: TLayout, bounds: {
    cols: number;
}): TLayout;
/**
 * Get a layout item by ID. Used so we can override later on if necessary.
 *
 * @param  {Array}  layout Layout array.
 * @param  {String} id     ID
 * @return {ILayoutItem}    Item at ID.
 */
export declare function getLayoutItem(layout: TLayout, id: string | number | undefined): ILayoutItem | undefined;
export declare function getAllCollisions(layout: TLayout, layoutItem: ILayoutItem): ILayoutItem[];
/**
 * Move an element. Responsible for doing cascading movements of other elements.
 *
 * @param  {TLayout}      layout              Full layout to modify.
 * @param  {ILayoutItem}  l                   element to move.
 * @param  {Number}       [x]                 X position in grid units.
 * @param  {Number}       [y]                 Y position in grid units.
 * @param  {Boolean}      [isUserAction]      If true, designates that the item we're moving is being dragged/resized by the user.
 * @param  {Boolean}      [horizontalShift]   If true, the GridItems will move left or right when the moving element is passing over a GridItem.
 * @param  {Boolean}      [preventCollision]  If true, the moving element will not be moving other elements to make space for a possible drop.
 * @return {TLayout}                          The updated layout.
 */
export declare function moveElement(layout: TLayout, l: ILayoutItem, x: number, y: number, isUserAction: boolean, horizontalShift: boolean, preventCollision?: boolean): TLayout;
/**
 * This is where the magic needs to happen - given a collision, move an element away from the collision.
 * We attempt to move it up if there's room, otherwise it goes below.
 *
 * @param  {TLayout} layout             Full layout to modify.
 * @param  {ILayoutItem} collidesWith   Layout item we're colliding with.
 * @param  {ILayoutItem} itemToMove     Layout item we're moving.
 * @param  {Boolean} [isUserAction]     If true, designates that the item we're moving is being dragged/resized by the user.
 * @param  {Boolean} [movingDirection]
 * @param  {Boolean} [horizontalShift]
 * @return {TLayout}                    The modified layout.
 */
export declare function moveElementAwayFromCollision(layout: TLayout, collidesWith: ILayoutItem, itemToMove: ILayoutItem, isUserAction: boolean, movingDirection: TMovingDirection, horizontalShift: boolean): TLayout;
export interface ITransformStyle {
    transform: string;
    WebkitTransform: string;
    MozTransform: string;
    msTransform: string;
    OTransform: string;
    width: string;
    height: string;
    position: `absolute` | `relative`;
}
/**
 * Returns default direction
 *
 * @param top
 * @param left
 * @param width
 * @param height
 * @returns {ITransformStyle}
 */
export declare function setTransform(top: number, left: number, width: number, height: number): ITransformStyle;
/**
 * Just like the setTransform method, but instead it will return a negative value of right.
 *
 * @param top
 * @param right
 * @param width
 * @param height
 * @returns {ITransformStyle}
 */
export declare function setTransformRtl(top: number, right: number, width: number, height: number): ITransformStyle;
export interface ITopLeftStyle {
    top: string;
    left: string;
    width: string;
    height: string;
    position: `absolute`;
}
export declare function setTopLeft(top: number, left: number, width: number, height: number): ITopLeftStyle;
export interface ITopRightStyle {
    top: string;
    right: string;
    width: string;
    height: string;
    position: string;
}
/**
 * Just like the setTopLeft method, but instead, it will return a right property instead of left.
 *
 * @param top
 * @param right
 * @param width
 * @param height
 * @returns {ITopRightStyle}
 */
export declare function setTopRight(top: number, right: number, width: number, height: number): ITopRightStyle;
/**
 * Validate a layout. Throws errors.
 *
 * @param  {Array}  layout        Array of layout items.
 * @param  {String} [contextName] Context name for errors.
 * @throw  {Error}                Validation error.
 */
export declare function validateLayout(layout: TLayout, contextName?: string): void;
/**
 * Hyphenate a camelCase string.
 *
 * @param {String} str
 * @return {String}
 */
